!function(e){function t(o){if(n[o])return n[o].exports;var r=n[o]={i:o,l:!1,exports:{}};return e[o].call(r.exports,r,r.exports,t),r.l=!0,r.exports}var n={};t.m=e,t.c=n,t.i=function(e){return e},t.d=function(e,n,o){t.o(e,n)||Object.defineProperty(e,n,{configurable:!1,enumerable:!0,get:o})},t.n=function(e){var n=e&&e.__esModule?function(){return e.default}:function(){return e};return t.d(n,"a",n),n},t.o=function(e,t){return Object.prototype.hasOwnProperty.call(e,t)},t.p="",t(t.s=1)}([function(e,t,n){var o,r,i;!function(n,a){r=[],o=a,void 0!==(i="function"==typeof o?o.apply(t,r):o)&&(e.exports=i)}(0,function(){"use strict";if("undefined"==typeof window||"undefined"==typeof navigator)return!1;var e,t,n,o,r,i,a,d,u,c,f,s=window.navigator.userAgent,p=void 0!==navigator.mimeTypes["application/pdf"],l=function(){return void 0!==window.Promise}(),v=function(){return-1!==s.indexOf("irefox")}(),m=function(){return!!v&&parseInt(s.split("rv:")[1].split(".")[0],10)>18}(),y=function(){return/iphone|ipad|ipod/i.test(s.toLowerCase())}();return o=function(e){var t;try{t=new ActiveXObject(e)}catch(e){t=null}return t},t=function(){return!!(window.ActiveXObject||"ActiveXObject"in window)},n=function(){return!(!o("AcroPDF.PDF")&&!o("PDF.PdfCtrl"))},e=!y&&(m||p||t()&&n()),r=function(e){var t,n="";if(e){for(t in e)e.hasOwnProperty(t)&&(n+=encodeURIComponent(t)+"="+encodeURIComponent(e[t])+"&");n&&(n="#"+n,n=n.slice(0,n.length-1))}return n},i=function(e){"undefined"!=typeof console&&console.log&&console.log("[PDFObject] "+e)},a=function(e){return i(e),!1},u=function(e){var t=document.body;return"string"==typeof e?t=document.querySelector(e):"undefined"!=typeof jQuery&&e instanceof jQuery&&e.length?t=e.get(0):void 0!==e.nodeType&&1===e.nodeType&&(t=e),t},c=function(e,t,n,o,r){var i=o+"?file="+encodeURIComponent(t)+n,a=y?"-webkit-overflow-scrolling: touch; overflow-y: scroll; ":"overflow: hidden; ",d="<div style='"+a+"position: absolute; top: 0; right: 0; bottom: 0; left: 0;'><iframe  "+r+" src='"+i+"' style='border: none; width: 100%; height: 100%;' frameborder='0'></iframe></div>";return e.className+=" pdfobject-container",e.style.position="relative",e.style.overflow="auto",e.innerHTML=d,e.getElementsByTagName("iframe")[0]},f=function(e,t,n,o,r,i,a){var d="";return d=t&&t!==document.body?"width: "+r+"; height: "+i+";":"position: absolute; top: 0; right: 0; bottom: 0; left: 0; width: 100%; height: 100%;",e.className+=" pdfobject-container",e.innerHTML="<embed "+a+" class='pdfobject' src='"+n+o+"' type='application/pdf' style='overflow: auto; "+d+"'/>",e.getElementsByTagName("embed")[0]},d=function(t,n,o){if("string"!=typeof t)return a("URL is not valid");n=void 0!==n&&n,o=void 0!==o?o:{};var i=o.id&&"string"==typeof o.id?"id='"+o.id+"'":"",d=!!o.page&&o.page,s=o.pdfOpenParams?o.pdfOpenParams:{},p=void 0===o.fallbackLink||o.fallbackLink,v=o.width?o.width:"100%",m=o.height?o.height:"100%",b="boolean"!=typeof o.assumptionMode||o.assumptionMode,g="boolean"==typeof o.forcePDFJS&&o.forcePDFJS,h=!!o.PDFJS_URL&&o.PDFJS_URL,w=u(n),P="",D="";return w?(d&&(s.page=d),D=r(s),g&&h?c(w,t,D,h,i):e||b&&l&&!y?f(w,n,t,D,v,m,i):h?c(w,t,D,h,i):(p&&(P="string"==typeof p?p:"<p>This browser does not support inline PDFs. Please download the PDF to view it: <a href='[url]'>Download PDF</a></p>",w.innerHTML=P.replace(/\[url\]/g,t)),a("This browser does not support embedded PDFs"))):a("Target element cannot be determined")},{embed:function(e,t,n){return d(e,t,n)},pdfobjectversion:"2.1.1",supportsPDFs:function(){return e}()}})},function(e,t,n){"use strict";var o=n(0),r=document.getElementById("pdf-container"),i=r.dataset.pdfPath;o.embed(i,"#pdf-container")}]);