// app.scss
//
// This main Sass file imports all partials and is compiled into the single
// CSS dependency for our HTML.
//
// This project uses an inuitcss architecture
// (https://github.com/inuitcss/inuitcss)


// ===========================================================================
// SETTINGS
// ===========================================================================
@import "inuitcss/settings/example.settings.config";
@import 'inuitcss/settings/settings.core';
@import "inuitcss/settings/example.settings.global";

@import 'sass-math-pow/sass/math-pow';
@import 'squared/scss/settings/fonts';
@import 'squared/scss/settings/colors';
@import 'squared/scss/settings/typography';
@import 'squared/scss/settings/layout';

// ===========================================================================
// TOOLS
// ===========================================================================
@import 'inuitcss/tools/tools.rem';
@import 'inuitcss/tools/tools.font-size';
@import 'inuitcss/tools/tools.clearfix';
@import 'inuitcss/tools/tools.hidden';
@import 'sass-mq/mq';


// ===========================================================================
// GENERIC
// ===========================================================================
@import 'inuitcss/generic/generic.box-sizing';
@import 'inuitcss/generic/generic.normalize';
@import 'inuitcss/generic/generic.reset';
@import 'inuitcss/generic/generic.shared';


// ===========================================================================
// ELEMENTS
// ===========================================================================
@import 'inuitcss/elements/elements.page';
@import 'inuitcss/elements/elements.headings';
@import 'inuitcss/elements/elements.images';
@import 'inuitcss/elements/elements.tables';

@import 'squared/scss/elements/page';
@import 'squared/scss/elements/headings';
@import 'squared/scss/elements/links';
@import 'squared/scss/elements/lists';


// ===========================================================================
// OBJECTS
// ===========================================================================
@import 'inuitcss/objects/objects.wrapper';
@import 'inuitcss/objects/objects.layout';
@import 'inuitcss/objects/objects.media';
@import 'inuitcss/objects/objects.flag';
@import 'inuitcss/objects/objects.list-bare';
@import 'inuitcss/objects/objects.list-inline';
@import 'inuitcss/objects/objects.box';
@import 'inuitcss/objects/objects.block';
@import 'inuitcss/objects/objects.ratio';
@import 'inuitcss/objects/objects.crop';
@import 'inuitcss/objects/objects.tables';
@import 'inuitcss/objects/objects.pack';

@import 'squared/scss/objects/icon';
@import 'squared/scss/objects/comma-list';


// ===========================================================================
// COMPONENTS
// ===========================================================================
@import 'squared/scss/components/universal-header';
@import 'squared/scss/components/lander-page';
@import 'squared/scss/components/lander-info-panel';
@import 'squared/scss/components/buttons';


// ===========================================================================
// UTILITIES
// ===========================================================================
@import 'inuitcss/utilities/utilities.clearfix';
$inuit-offsets: true;
@import 'inuitcss/utilities/utilities.widths';
@import 'inuitcss/utilities/utilities.headings';
@import 'inuitcss/utilities/utilities.spacing';
@import 'inuitcss/utilities/utilities.print';

@import 'inuitcss/utilities/utilities.hide';

@import 'squared/scss/utilities/links';
