<div class="lander-container lander-container--footer">

  <footer class="lander-footer">
    <p>© 2018 Association of Universities for Research in Astronomy, Inc.</p>

    <p>LSST documentation is delivered by <a href="https://fastly.com">Fastly</a>.</p>

    <p>Financial support for <a href="https://www.lsst.org">LSST</a> comes from the National Science Foundation (<a href="https://nsf.gov">NSF</a>) through Cooperative Agreement No. <a href="https://www.nsf.gov/awardsearch/showAward?AWD_ID=1258333">1258333</a>, the Department of Energy (<a href="https://energy.gov">DOE</a>) Office of Science under Contract No. <a href="http://www-group.slac.stanford.edu/legal/contract.asp">DE-AC02-76SF00515</a>, and private funding raised by the <a href="https://www.lsstcorporation.org">LSST Corporation</a>. The NSF-funded <a href="https://project.lsst.org">LSST Project Office</a> for construction was established as an operating center under management of the Association of Universities for Research in Astronomy (<a href="http://www.aura-astronomy.org">AURA</a>). The DOE-funded effort to build the LSST camera is managed by the SLAC National Accelerator Laboratory (<a href="https://www6.slac.stanford.edu/">SLAC</a>).</p>

    <p>This page is generated by the <a href="https://github.com/lsst-sqre/lander">Lander</a> project. <a href="https://octicons.github.com">Icons</a> by GitHub.</p>
  </footer>
</div>
